<?php
/**
 * FSF Member Dashboard
 * Copyright © 2014 Free Software Foundation, Inc.
 *
 * This file is a part of FSF Member Dashboard.
 *
 * FSF Member Dashboard is free software; you can copy, modify, and
 * distribute it under the terms of the GNU Affero General Public
 * License Version 3, 19 November 2007 and the CiviCRM Licensing
 * Exception.
 *
 * FSF Member Dashboard is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FSF Member Dashboard.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

require_once 'CRM/Core/Page.php';

class CRM_Memberdashboard_Page_MemberDashboard extends CRM_Memberdashboard_Page {
  /**
   * Return the personalized title for the page.
   *
   * @return Title string
   */
  function pageTitle() {
    return ts('Welcome, ') . $this->contact['first_name'] . '!';
  }

  /**
   * There isn't a function that does this simple task in the PCP BAO,
   * surprisingly.
   */
  function campaignPages() {
    $dao = CRM_Core_DAO::executeQuery(
      'SELECT id, title, is_active, is_honor_roll FROM civicrm_pcp WHERE contact_id=%1',
      array( 1 => array($this->contact['id'], 'Integer') )
    );

    $pages = array();

    while($dao->fetch()) {
      $pages[] = array(
        'id' => $dao->id,
        'title' => $dao->title,
        'is_active' => $dao->is_active,
        'is_honor_roll' => $dao->is_honor_roll
      );
    }

    $dao->free();

    return $pages;
  }

  function makeChecksum() {
    return CRM_Contact_BAO_Contact_Utils::generateChecksum($this->contact['id']);
  }

  function run() {
    $helper = new CRM_Memberdashboard_Page_ComponentHelper(array(
      'CiviMember',
      'CiviContribute'
    ));
    $helper->run();

    $this->assign('dashboardElements', $helper->buildDashboardElements());
    $this->assign('campaignPages', $this->campaignPages());
    // Checksum for editing recurring contributions.
    $this->assign('contributionChecksum', $this->makeChecksum());
    $this->assign('contactId', $this->contact['id']);

    parent::run();

    CRM_Utils_System::setTitle($this->pageTitle());
  }
}
